<!-- docs/_sidebar.md -->

- Core

  - [Manage asdf-vm](core-manage-asdf-vm)
  - [Manage Plugins](core-manage-plugins)
  - [Manage Versions](core-manage-versions)
  - [Configuration](core-configuration)
  - [All Commands](core-commands)

- Plugins

  - [Creating Plugins](plugins-create)
  - [All Plugins](plugins-all) <!-- pulls in asdf-vm/asdf-plugins readme -->

- Contributing

  - [Core asdf vm](contributing-core-asdf-vm)
  - [Documentation Site](contributing-doc-site)

- [Changelog](changelog) <!-- pulls in changelog from repo -->
- [Thanks](thanks)
